==> haskell-ranged-sets-0.3.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Ranged-sets
version: 0.3.0
id: Ranged-sets-0.3.0-8gFs7ALmLaUFZYpRw3Mued
key: Ranged-sets-0.3.0-8gFs7ALmLaUFZYpRw3Mued
license: BSD-3-Clause
copyright: Paul Johnson, 2005, 2006, 2007, 2008
maintainer: paul@cogito.org.uk
author: Paul Johnson
stability: beta
homepage: http://code.haskell.org/ranged-sets
synopsis: Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:
    .
    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)
    .
    Alternatively you can have all strings s such that:
    .
    >    ("F" <= s < "G")
category: Data
abi: 1e3c5e57c41c2ae5b22d998f2bfe4867
exposed: True
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges
import-dirs: /usr/lib/ghc-8.6.1/site-local/Ranged-sets-0.3.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/Ranged-sets-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/Ranged-sets-0.3.0
hs-libraries: HSRanged-sets-0.3.0-8gFs7ALmLaUFZYpRw3Mued
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html: /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ranged-sets-0.3.0-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Ranged-sets
version: 0.3.0
id: Ranged-sets-0.3.0-CC1V5NY7IQOAjYlk1GL9wL
key: Ranged-sets-0.3.0-CC1V5NY7IQOAjYlk1GL9wL
license: BSD-3-Clause
copyright: Paul Johnson, 2005, 2006, 2007, 2008
maintainer: paul@cogito.org.uk
author: Paul Johnson
stability: beta
homepage: http://code.haskell.org/ranged-sets
synopsis: Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:
    .
    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)
    .
    Alternatively you can have all strings s such that:
    .
    >    ("F" <= s < "G")
category: Data
abi: 0498fd45be6d4ad528fc4405f2e3b6d6
exposed: True
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges
import-dirs: /usr/lib/ghc-8.6.3/site-local/Ranged-sets-0.3.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/Ranged-sets-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/Ranged-sets-0.3.0
hs-libraries: HSRanged-sets-0.3.0-CC1V5NY7IQOAjYlk1GL9wL
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.12.6.1-4a6Ozz7bfHzLQyA4XOD1Dc base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html: /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
